@@ -89,7 +89,7 @@ if _is_proxy_model_creation_possible():
 
     for language in settings.LANGUAGES:
         if (
-            getattr(settings, 'ALGOLIA_IS_ENABLE_ENV_SPECIFIC_INDEXES') and
+            getattr(settings, 'ALGOLIA_IS_ENABLE_ENV_SPECIFIC_INDEXES', False) and
             hasattr(settings, 'DJANGO_ENV')
         ):
             index_name = f'{settings.DJANGO_ENV.value}_cms_pages_{language[0]}'
